Primeiros passos com Databases for PostgreSQL

Este tutorial o orienta nas etapas para começar a usar o Databases for PostgreSQL rapidamente, provisionando uma instância, configurando o pgAdmin,, definindo sua senha de administrador e configurando o registro e o monitoramento.

Siga estas etapas para concluir o tutorial:

Siga estas etapas para concluir o tutorial:

Siga estas etapas para concluir o tutorial:

Siga estas etapas para concluir o tutorial:

Antes de Iniciar

Etapa 1: Provisionar por meio do Console

  1. Efetue login no console do IBM Cloud.

  2. Clique no Databases for PostgreSQL serviço no catálogo.

  3. Em Detalhes do serviço, configure o seguinte:

    • Nome do serviço — O nome pode ser qualquer sequência de caracteres e é o nome utilizado na web e na CLI para identificar a nova implantação.
    • Grupo de recursos — Se você estiver organizando seus serviços em grupos de recursos, especifique o grupo de recursos neste campo. Caso contrário, é possível deixá-lo como o padrão. Para obter mais informações, consulte Gerenciando grupos de recursos.
    • Localização- A região da nuvem pública da implantação.
  4. Alocação de recurso-Especifique a RAM, o disco e os cores iniciais para seus bancos de dados. Os tamanhos mínimos de memória e de disco são selecionados por padrão. Ao usar núcleos dedicados, um grupo de recursos recebe um host de locatário úinico, com uma reserva mínima garantida de frações da CPU. Em seguida, é atribuído às suas implantações o número de núcleos que você especificar. Uma vez provisionado, o disco não pode ter a capacidade reduzida.

  5. Na configuração do serviço, configure o seguinte:

    • Versão do banco de dados Set only at deployment- A versão de implantação do seu banco de dados. Para assegurar desempenho ideal, execute a versão preferencial. Automaticamente, utiliza-se a versão secundária mais recente. Para obter mais informações, consulte a política de controle de versões do banco de dados.
    • Criptografia-Se você usar Key Protect, uma instância e chave poderão ser selecionadas para criptografar o disco da implementação. Se você não usar sua chave, a implementação criará e gerenciará automaticamente a própria chave de criptografia de disco.
    • Pontos de extremidade Set only at deployment- Configure ospontos de extremidade do serviço em sua implantação.

    Depois de definir as configurações adequadas, clique em “Criar” para iniciar o processo de provisionamento. A página Databases for PostgreSQL Lista de recursos é aberta.

  6. Clique em Criar. A página Cloud Databases Lista de recursos é aberta.

  7. Quando sua instância for provisionada, clique no nome da instância para ver mais informações.

Etapa 1: Provisionar por meio da CLI

É possível provisionar uma instância do Databases for PostgreSQL por meio da CLI. Se você ainda não o tiver, será necessário instalar a IBM Cloud CLI.

  1. Efetue login no IBM Cloud com o comando a seguir:

    ibmcloud login
    

    Se você usar um ID de usuário federado, é importante que mude para um código de acesso único (ibmcloud login --sso) ou utilize uma chave de API (ibmcloud --apikey key ou @key_file) para se autenticar. Para obter mais informações sobre como fazer login usando a CLI, consulte “Comandos gerais da CLI(ibmcloud) ” em ibmcloud login.

  2. Crie uma instância do Databases for PostgreSQL.

    Selecione um dos métodos a seguir:

    • Para criar uma instância por meio da CLI no plano Enterprise, execute o seguinte comando:
        ibmcloud resource service-instance-create <INSTANCE_NAME> <SERVICE_NAME> <SERVICE_PLAN_NAME> <LOCATION> <SERVICE_ENDPOINTS_TYPE> <RESOURCE_GROUP>
        ```
    Os campos no comando estão descritos na tabela a seguir.
    
    | Campo | Descrição | Sinalize |
    |-------|------------|------------|
    | `NAME` [Required]{: tag-red} | O nome da instância pode ser qualquer sequência de caracteres e é o nome utilizado na web e na CLI para identificar a nova implantação. |  |
    | `SERVICE_NAME` [Required]{: tag-red} | Nome ou ID do serviço. Para Databases for PostgreSQL, use `databases-for-postgresql`. |  |
    | `SERVICE_PLAN_NAME` [Required]{: tag-red} | Plano padrão (`standard`) |  |
    | `LOCATION` [Required]{: tag-red} | O local onde você deseja fazer a implantação. Para obter uma lista de regiões, use o comando `ibmcloud regions`. |  |
    | `SERVICE_ENDPOINTS_TYPE` | Configure os [pontos de extremidade de serviço](/docs/cloud-databases?topic=cloud-databases-service-endpoints) de sua implementação, seja `public` ou `private`. |  |
    | `RESOURCE_GROUP` | O nome do grupo de recursos.  O valor padrão é `default`. | -g |
    | `--parameters` | Arquivo JSON ou sequência JSON de parâmetros para criar a instância de serviço | -p |
    {: caption="Campos de formato de comando básico" caption-side="top"}
    
    Você vê uma resposta como esta:
    
    ```text {: codeblock}
    Creating service instance INSTANCE_NAME in resource group default of account    USER...
    OK
    Service instance INSTANCE_NAME was created.
    Name:                INSTANCE_NAME
    ID:                  crn:v1:bluemix:public:databases-for-postgresql:us-east:a/   40ddc34a846383BGB5b60e:dd13152c-fe15-4bb6-af94-fde0af5303f4::
    GUID:                dd13152c-fe15-4bb6-af94-fde0af56897
    Location:            LOCATION
    State:               provisioning
    Type:                service_instance
    Sub Type:            Public
    Service Endpoints:   private
    Allow Cleanup:       false
    Locked:              false
    Created at:          2023-06-26T19:42:07Z
    Updated at:          2023-06-26T19:42:07Z
    Last Operation:
                        Status    create in progress
                        Message   Started create instance operation
    
  3. Para verificar o status do provisionamento, use o seguinte comando:

    ibmcloud resource service-instance <INSTANCE_NAME>
    

    Ao concluir, você verá uma resposta como:

    Retrieving service instance INSTANCE_NAME in resource group default under account USER's Account as USER...
    OK
    Name:                  INSTANCE_NAME
    ID:                    crn:v1:bluemix:public:databases-for-postgresql:us-east:a/40ddc34a953a8c02f109835656860e:dd13152c-fe15-4bb6-af94-fde0af5303f4::
    GUID:                  dd13152c-fe15-4bb6-af94-fde5654765
    Location:              <LOCATION>
    Service Name:          databases-for-postgresql
    Service Plan Name:     standard
    Resource Group Name:   default
    State:                 active
    Type:                  service_instance
    Sub Type:              Public
    Locked:                false
    Service Endpoints:     private
    Created at:            2023-06-26T19:42:07Z
    Created by:            USER
    Updated at:            2023-06-26T19:53:25Z
    Last Operation:
                           Status    create succeeded
                           Message   Provisioning PostgreSQL with version 12 (100%)
    
  4. (Opcional) Excluindo uma instância de serviço Exclua uma instância executando um comando como este:

    ibmcloud resource service-instance-delete <INSTANCE_NAME>
    

Conecte-se ao seu banco de dados usando a CLI

Localize os comandos apropriados para conectar-se ao seu banco de dados por meio da CLI no Cloud Databases CLI Reference e Conectando-se com psql.

O comando ibmcloud cdb deployment-connections cuida de tudo o que está envolvido na criação de uma conexão via CLI. Por exemplo, para se conectar a uma implantação chamada “example-postgres”, use um comando como:

ibmcloud cdb deployment-connections example-postgres --start

O comando solicita a senha de administrador e, em seguida, executa a CLI do psql para se conectar ao banco de dados. Para instalar o plug-in Cloud Databases, consulte Conectando com a documentação do psql aqui.

O parâmetro --parameters

O comando service-instance-create suporta o sinalizador -p , que permite que parâmetros no formato JSON sejam passados para o processo de provisionamento. Alguns valores de parâmetros são Nomes de Recursos na Nuvem (CRNs), que identificam de forma exclusiva um recurso na nuvem. Todos os nomes de parâmetros e valores são transmitidos como sequências.

Por exemplo, se um banco de dados estiver sendo provisionado a partir de um backup específico e a implantação do novo banco de dados precisar de um total de 9 GB de memória distribuídos entre três membros, o comando para provisionar 3 GB por membro seria o seguinte:

ibmcloud resource service-instance-create databases-for-postgresql <SERVICE_NAME> standard us-south \
-p \ '{
  "backup_id": "crn:v1:blue:public:databases-for-postgresql:us-south:a/54e8ffe85dcedf470db5b5ee6ac4a8d8:1b8f53db-fc2d-4e24-8470-f82b15c71717:backup:06392e97-df90-46d8-98e8-cb67e9e0a8e6",
  "members_memory_allocation_mb": "3072"
}'

Etapa 1: Provisionar por meio da API do controlador de recurso

Siga estas etapas para provisionar usando a API do controlador de recurso

  1. Obtenha um token IAM a partir do seu token de API.

  2. É necessário saber o ID do grupo de recursos no qual você gostaria de implementar. Essas informações estão disponíveis por meio da CLI da IBM Cloud.

    Use um comando como:

    ibmcloud resource groups
    
  3. Você precisa saber em qual região deseja fazer a implantação.

    Para listar todas as regiões nas quais as implementações podem ser provisionadas a partir da região atual, use o plug-in da CLI do Cloud Databases.

    O comando é semelhante a:

    ibmcloud cdb regions --json
    

    Quando tiver todas as informações, provisione uma nova instância de recurso com o controlador de recurso IBM Cloud.

    curl -X POST \
      https://resource-controller.cloud.ibm.com/v2/resource_instances \
      -H 'Authorization: Bearer <>' \
      -H 'Content-Type: application/json' \
        -d '{
        "name": "my-instance",
        "target": "blue-us-south",
        "resource_group": "5g9f447903254bb58972a2f3f5a4c711",
        "resource_plan_id": "databases-for-postgresql-standard"
      }'
    

    Os parâmetros name, target, resource_group e resource_plan_id são todos necessários.

Lista de parâmetros adicionais

  • backup_id - Um CRN de um recurso de backup do qual restaurar. O backup deve ser criado por meio de uma implantação de banco de dados com o mesmo ID de serviço. O backup é carregado após o fornecimento e a nova implementação que usa esses dados é inicializada. Um CRN de backup está no formato crn:v1:<...>:backup:<uuid>. Se omitido, o banco de dados será provisionado vazio.

  • version - A versão do banco de dados a ser provisionado. Se omitido, o banco de dados será criado com a versão principal e secundária mais recentes.

  • disk_encryption_key_crn- O CRN de uma chave KMS ( Key Protect ), que é então usado para criptografia de disco. O CRN de uma chave KMS tem o formato crn:v1:<...>:key:<id>.

  • backup_encryption_key_crn- O CRN de uma chave KMS (por exemplo, [Key Protect ), que é usada para criptografia de backup. O CRN de uma chave KMS tem o formato crn:v1:<...>:key:<id>.

    Para usar uma chave para seus backups, deve-se primeiro ativar a delegação de serviço para serviço.

  • members_memory_allocation_mb - Quantidade total de memória a ser compartilhada entre os membros do banco de dados dentro do banco de dados. Por exemplo, se o valor for "6144" e houver três membros do banco de dados, a implementação terá 6 GB de RAM no total, totalizando 2 GB de RAM por membro. Se omitido, o valor padrão usado para o tipo de banco de dados será usado.

  • members_disk_allocation_mb - Quantidade total de disco a ser compartilhada entre os membros do banco de dados dentro do banco de dados. Por exemplo, se o valor for "30720" e houver três membros, a implementação terá 30 GB de disco no total, totalizando 10 GB de disco por membro. Se omitido, o valor padrão para o tipo de banco de dados será usado.

  • members_cpu_allocation_count - Ativa e aloca o número de núcleos dedicados especificados para a sua implementação. Por exemplo, para usar dois núcleos dedicados por membro, use "members_cpu_allocation_count":"2". Se omitido, o valor padrão "CPU compartilhada" usará recursos de cálculo em hosts compartilhados.

  • service_endpoints- Os pontos de extremidade de serviço suportados em sua implementação, public ou private. Esse é um parâmetro requerido.

Etapa 1: Provisionar por meio do Terraform

Use o Terraform para gerenciar sua infraestrutura por meio do ibm_database Resource for Terraform.. Como alternativa, você pode usar os módulos do Terraform IBM para gerenciar sua infraestrutura por meio dos módulos do Terraform IBM para Databases for PostgreSQL.

Usando APIs

Use a API Cloud Databases para trabalhar com sua instância Databases for PostgreSQL. A API do controlador de recurso é usada para provisionar uma instância

Etapa 2: Definir a senha do administrador

O usuário administrativo

Quando você provisiona uma implementação do Databases for PostgreSQL, um usuário administrador é criado automaticamente.

Configure a senha do administrador antes de usá-la para se conectar

Ao provisionar uma nova implantação no IBM Cloud, você recebe automaticamente uma conta de usuário admin para acessar e gerenciar o PostgreSQL. Depois de definir a senha de administrador, use-a para se conectar à sua implantação.

Quando admin cria um recurso em um banco de dados, como uma tabela, admin é o proprietário desse objeto. Os recursos criados por admin não estão acessíveis a outros usuários, a menos que você conceda permissão expressa a eles.

A maior diferença entre o usuário “ admin ” e quaisquer outros usuários que você adicionar à sua implantação é o pg_monitor e pg_signal_backend funções. A função pg_monitor fornece um conjunto de permissões que torna o usuário administrativo apropriado para monitorar o servidor de banco de dados. A função pg_signal_backend fornece ao usuário administrativo a capacidade de enviar sinais para cancelar as consultas e as conexões iniciadas por outros usuários. Ele não é capaz de enviar sinais para processos pertencentes a superusuários.

Você também pode usar o usuário admin para conceder essas duas funções a outros usuários em sua implantação.

Para permitir que outros usuários do banco de dados possam cancelar consultas, conceda a função “ pg_signal_backend ” ao usuário “ admin ”. Use um comando como:

GRANT pg_signal_backend TO joe;

Para permitir que o usuário joe cancele os backends, conceda pg_signal_backend a todos os usuários com a função ibm-cloud-base-user com um comando como:

GRANT pg_signal_backend TO "ibm-cloud-base-user";

Esse privilégio permite que o usuário ou usuários finalizem quaisquer conexões com o banco de dados.

Para configurar um usuário de monitoramento específico, mary, use um comando como:

GRANT pg_monitor TO mary;

Conceda pg_signal_backend a todos os usuários com a função ibm-cloud-base-user com um comando como:

GRANT pg_monitor TO "ibm-cloud-base-user";

Configuração da senha de administrador na interface do usuário

Configure sua Senha de administrador por meio da IU selecionando sua instância na lista de recursos no IBM Cloud Painel. Em seguida, selecione Configurações.. Em seguida, selecione Mudar senha do administrador de banco de dados

Definir a senha do administrador por meio da CLI

Use o comando cdb user-password do plug-in IBM Cloud CLI Cloud Databases para configurar a senha do administrador.

Por exemplo, para definir a senha de administrador de uma implantação chamada example-deployment, use o seguinte comando:

ibmcloud cdb user-password example-deployment admin <newpassword>

Definir a senha do administrador por meio da API

O Endpoint da Fundação, exibido na seção “Visão geral dos detalhes da implantação” do seu serviço, fornece o end URL de base para acessar essa implantação por meio da API. Use-o com o terminal Configurar a senha do usuário especificado para configurar a senha do administrador

curl -X PATCH `https://api.{region}.databases.cloud.ibm.com/v5/ibm/deployments/{id}/users/admin` \
-H `Authorization: Bearer <>` \
-H `Content-Type: application/json` \
-d `{"password":"newrootpasswordsupersecure21"}` \

Definir a senha do administrador por meio do Terraform

Para configurar a senha do Administrador, use a API:

O Endpoint da Fundação, exibido na seção “Visão geral dos detalhes da implantação” do seu serviço, fornece o end URL de base para acessar essa implantação por meio da API. Use-o com o terminal Configurar a senha do usuário especificado para configurar a senha do administrador

curl -X PATCH `https://api.{region}.databases.cloud.ibm.com/v5/ibm/deployments/{id}/users/admin` \
-H `Authorization: Bearer <>` \
-H `Content-Type: application/json` \
-d `{"password":"newrootpasswordsupersecure21"}` \

Você também pode usar a CLI:

Use o comando cdb user-password do plug-in IBM Cloud CLI Cloud Databases para configurar a senha do administrador.

Por exemplo, para definir a senha de administrador de uma implantação chamada example-deployment, use o seguinte comando:

ibmcloud cdb user-password example-deployment admin <newpassword>

Para definir a senha de administrador por meio da interface do usuário, siga estas etapas:

Defina sua senha de administrador por meio da interface do usuário, selecionando sua instância na lista de recursos no painel IBM Cloud. Em seguida, selecione Configurações.. Em seguida, selecione Change Database admin password (Alterar senha do administrador do banco de dados ).

Etapa 3: Configurar pgAdmin

O pgAdmin é executado como um servidor e você se conecta a ele por meio de um navegador. Quando o servidor é iniciado, ele é executado no host local, no padrão http://127.0.0.1:53113/browser/.

Ao abrir o pgAdmin pela primeira vez, você recebe um prompt para configurar uma senha primária. Essa senha é diferente da senha da sua instância, pois é usada especificamente pelo pgAdmin para armazenar as senhas dos seus servidores PostgreSQL ou da sua instância PostgreSQL.

O Painel tem uma tela Bem-vindo. Em Links rápidos, clique em Incluir novo servidor.

Na página “Visão geral” da sua instância, há um painel “Endpoints” com todas as informações relevantes de conexão.

Em pgAdmin,, forneça ao pgAdmin as informações necessárias para se conectar à sua instância.

Primeiro, preencha as informações Conexão,

  • No campo “Nome/endereço do host ”, use o nome do host da sua instância.
  • Para a porta, use a porta da sua instância.
  • O Banco de dados de manutenção permanece postgres.
  • Para o nome de usuário e a senha, use as credenciais do admin que você definiu após o provisionamento da sua instância. É possível escolher pgAdmin para salvar a senha.
  • Os campos Função e Serviço podem ser deixados vazios.

Em seguida, configure as configurações SSL.

  • Copie as informações do certificado no painel “Endpoints” da página “ Dashboard overview ” da sua instância.
  • Salve o certificado em um arquivo. (É possível usar o nome fornecido no download ou de seu próprio arquivo.)
  • Configure o campo Modo SSL para Verify-Full.
  • No campo “Certificado raiz”, selecione o arquivo onde você salvou o certificado da sua instância.

De volta à guia “Geral”, dê um nome à sua instância e adicione quaisquer comentários que deseje para descrevê-la ou identificá-la em pgAdmin.

Se o campo “Conectar agora?” estiver marcado, o pgAdmin tentará se conectar à sua instância quando você clicar no botão “Salvar ”.

Uso pgAdmin

Assim que o pgAdmin se conectar, sua instância aparecerá na lista “Servidores” e você terá acesso a um painel com informações e estatísticas.

Na lista de bancos de dados no Navegador, há o banco de dados postgres, ao qual você está conectado, e o banco de dados ibmclouddb, que é o banco de dados padrão para todas as implementações do Databases for PostgreSQL. Clique em ibmclouddb para se conectar a ele e expandir as informações sobre ele.

Use pgAdmin para visualizar, administrar e gerenciar seus dados e bancos de dados em sua instância do Databases for PostgreSQL. Para obter mais informações, consulte pgAdmin documentação.

Os recursos administrativos que requerem um superusuário não estão disponíveis por meio do pgAdmin porque o acesso de superusuário não está disponível para os usuários de uma implementação do Databases for PostgreSQL.

Etapa 4: Configurar restrições baseadas em contexto

As restrições baseadas no contexto permitem que os proprietários e administradores de contas definam e apliquem restrições de acesso aos recursos d IBM Cloud®, com base no contexto das solicitações de acesso. O acesso aos recursos do Cloud Databases pode ser controlado com restrições baseadas em contexto e políticas do Identity and Access Management (IAM).

Para configurar restrições baseadas em contexto para sua instância do Databases for PostgreSQL, siga as etapas em Protegendo recursos do Cloud Databases com restrições baseadas em contexto.

Etapa 5: Conectar IBM Cloud Monitoring por meio do console

É possível usar o IBM Cloud Monitoring para obter visibilidade operacional sobre o desempenho e o funcionamento de seus aplicativos, serviços e plataformas. O IBM Cloud Monitoring fornece administradores, equipes do DevOps e desenvolvedores de telemetria de pilha completa com recursos avançados para monitorar e solucionar problemas, definir alertas e projetar painéis customizados.

Para obter mais informações sobre como usar Monitoring com Databases for PostgreSQL, consulte Integração de monitoramento.

Etapa 5: Conectar IBM Cloud Monitoring por meio da CLI

É possível usar o IBM Cloud Monitoring para obter visibilidade operacional sobre o desempenho e o funcionamento de seus aplicativos, serviços e plataformas. O IBM Cloud Monitoring fornece administradores, equipes do DevOps e desenvolvedores de telemetria de pilha completa com recursos avançados para monitorar e solucionar problemas, definir alertas e projetar painéis customizados.

Para obter mais informações sobre como usar Monitoring com Databases for PostgreSQL, consulte Integração de monitoramento.

Não é possível conectar-se ao site IBM Cloud Monitoring usando a CLI. Use o console para concluir esta tarefa. Para obter mais informações, consulte Monitoramento da integração.

Etapa 5: conectar o IBM Cloud Monitoring por meio da API

É possível usar o IBM Cloud Monitoring para obter visibilidade operacional sobre o desempenho e o funcionamento de seus aplicativos, serviços e plataformas. O IBM Cloud Monitoring fornece administradores, equipes do DevOps e desenvolvedores de telemetria de pilha completa com recursos avançados para monitorar e solucionar problemas, definir alertas e projetar painéis customizados.

Para obter mais informações sobre como usar Monitoring com Databases for PostgreSQL, consulte Integração de monitoramento.

Não é possível conectar-se ao site IBM Cloud Monitoring usando a CLI. Use o console para concluir esta tarefa. Para obter mais informações, consulte Monitoramento da integração.

Etapa 5: Conectar IBM Cloud Monitoring por meio do Terraform

É possível usar o IBM Cloud Monitoring para obter visibilidade operacional sobre o desempenho e o funcionamento de seus aplicativos, serviços e plataformas. O IBM Cloud Monitoring fornece administradores, equipes do DevOps e desenvolvedores de telemetria de pilha completa com recursos avançados para monitorar e solucionar problemas, definir alertas e projetar painéis customizados.

Para obter mais informações sobre como usar Monitoring com Databases for PostgreSQL, consulte Integração de monitoramento.

Não é possível conectar-se ao site IBM Cloud Monitoring usando a CLI. Use o console para concluir esta tarefa. Para obter mais informações, consulte Monitoramento da integração.

Etapa 6: Conectar IBM Cloud Activity Tracker Event Routing

IBM Cloud® Activity Tracker Event Routing permite visualizar, gerenciar e auditar a atividade do serviço para cumprir as políticas corporativas e as normas do setor. Activity Tracker Event Routing registra as atividades iniciadas pelo usuário que alteram o estado de um serviço em IBM Cloud. Use o Activity Tracker Event Routing para acompanhar como os usuários e os aplicativos interagem com o serviço Databases for PostgreSQL.

Para começar a trabalhar com Activity Tracker Event Routing, consulte Getting started with IBM Cloud® Activity Tracker Event Routing.

O Activity Tracker Event Routing pode ter apenas uma instância por local. Para visualizar eventos, deve-se acessar a IU da web do serviço do IBM Cloud® Activity Tracker Event Routing no mesmo local em que a sua instância de serviço estiver disponível.

Para obter mais informações sobre eventos específicos de Databases for PostgreSQL, consulte Eventos de rastreamento de atividades.

Os eventos são formatados de acordo com o padrão Cloud Auditing Data Federation (CADF). Para obter detalhes adicionais sobre as informações que eles incluem, consulte Padrão CADF

Etapa 6: Conecte-se a IBM Cloud Activity Tracker Event Routing por meio da CLI

IBM Cloud® Activity Tracker Event Routing permite visualizar, gerenciar e auditar a atividade do serviço para cumprir as políticas corporativas e as normas do setor. Activity Tracker Event Routing registra as atividades iniciadas pelo usuário que alteram o estado de um serviço em IBM Cloud. Use o Activity Tracker Event Routing para acompanhar como os usuários e os aplicativos interagem com o serviço Databases for PostgreSQL.

Para começar a usar o site Activity Tracker Event Routing, consulte Getting Started with Activity Tracker Event Routing.

O Activity Tracker Event Routing pode ter apenas uma instância por local. Para visualizar eventos, deve-se acessar a IU da web do serviço do Activity Tracker Event Routing no mesmo local em que a sua instância de serviço estiver disponível. Para obter mais informações, consulte Ativar a IU da Web

Para obter mais informações sobre eventos específicos de Databases for PostgreSQL, consulte Eventos de rastreamento de atividades.

Os eventos são formatados de acordo com o padrão Cloud Auditing Data Federation (CADF). Para obter detalhes adicionais sobre as informações que eles incluem, consulte Padrão CADF

Não é possível conectar-se ao site Activity Tracker Event Routing usando a CLI. Use o console para concluir esta tarefa. Para obter mais informações, consulte Eventos de rastreamento de atividades.

Etapa 6: Conecte-se a IBM Cloud® Activity Tracker Event Routing por meio da API

IBM Cloud Activity Tracker Event Routing permite que você visualize, gerencie e audite a atividade do serviço para cumprir as políticas corporativas e as regulamentações do setor. Activity Tracker Event Routing registra as atividades iniciadas pelo usuário que alteram o estado de um serviço no IBM Cloud. Use o Activity Tracker Event Routing para acompanhar como os usuários e os aplicativos interagem com o serviço Databases for PostgreSQL.

Para começar a usar o Activity Tracker Event Routing, consulte [Getting Started with Activity Tracker Event Routing]/docs/atracker?topic=atracker-getting-started){: external}.

O Activity Tracker Event Routing pode ter apenas uma instância por local. Para visualizar eventos, deve-se acessar a IU da web do serviço do Activity Tracker Event Routing no mesmo local em que a sua instância de serviço estiver disponível. Para obter mais informações, consulte Ativar a IU da Web

Para obter mais informações sobre eventos específicos de Databases for PostgreSQL, consulte Eventos de rastreamento de atividades.

Os eventos são formatados de acordo com o padrão Cloud Auditing Data Federation (CADF). Para obter detalhes adicionais sobre as informações que eles incluem, consulte Padrão CADF

Você não pode se conectar ao site Activity Tracker Event Routing usando a API. Use o console para concluir esta tarefa. Para obter mais informações, consulte Eventos de rastreamento de atividades.

Etapa 6: Conectar IBM Cloud Activity Tracker Event Routing por meio do Terraform

IBM Cloud® Activity Tracker Event Routing permite visualizar, gerenciar e auditar a atividade do serviço para cumprir as políticas corporativas e as normas do setor. Activity Tracker Event Routing registra as atividades iniciadas pelo usuário que alteram o estado de um serviço em IBM Cloud. Use o Activity Tracker Event Routing para acompanhar como os usuários e os aplicativos interagem com o serviço Databases for PostgreSQL.

Para começar a usar o site Activity Tracker Event Routing, consulte Getting Started with Activity Tracker Event Routing.

O Activity Tracker Event Routing pode ter apenas uma instância por local. Para visualizar eventos, deve-se acessar a IU da web do serviço do Activity Tracker Event Routing no mesmo local em que a sua instância de serviço estiver disponível. Para obter mais informações, consulte Ativar a IU da Web

Para obter mais informações sobre eventos específicos de Databases for PostgreSQL, consulte Eventos de rastreamento de atividades.

Os eventos são formatados de acordo com o padrão Cloud Auditing Data Federation (CADF). Para obter detalhes adicionais sobre as informações que eles incluem, consulte Padrão CADF

Você não pode se conectar ao site Activity Tracker Event Routing usando a API. Use o console para concluir esta tarefa. Para obter mais informações, consulte Eventos de rastreamento de atividades.

Próximas etapas